﻿#ifndef TRRO_REMOTE_H
#define TRRO_REMOTE_H

#include <stddef.h>
#define USE_CSHARP 1
#ifdef WIN32
#include <windows.h>
typedef HWND WindowIdType;

#ifdef TRRO_EXPORTS
#define TRRO_EXPORT __declspec(dllexport)
#else
#define TRRO_EXPORT __declspec(dllimport)
#endif

#ifdef USE_CSHARP
#define STD_CALL __stdcall 
#else
#define STD_CALL
#endif // USE_CSHARP

#else
typedef void* WindowIdType;
typedef void* HWND;
#define TRRO_EXPORT __attribute__((visibility("default")))
#define STD_CALL
#endif

#ifdef _MSC_VER
#define DEPRECATED __declspec(deprecated)
#elif defined(__GNUC__) || defined(__clang__)
#define DEPRECATED __attribute__((deprecated))
#else
#define DEPRECATED
#endif


/* 通用错误码 */
#define TRRO_SUCCED           		0x00000001 // 1
#define TRRO_GWID_NOT_FOUND         0x00000010 // 16
#define TRRO_PARAM_INVALID          0x00F00000 // 15728640
#define TRRO_COMMON_ERROR           0x00FFFFFF // 16777215 参数输入或初始化状态异常

/* 配置文件加载模块 */
#define TRRO_CONFIG_ERROR            0x01FFFFFF // 33554431:配置模块通用失败
#define TRRO_CONFIG_PARSE_FAILED     0x01000002 // 16777218:配置文件格式异常，最常见
#define TRRO_CONFIG_ILLEGAL          0x01000003 // 16777219:参数格式非法，需新增参数检查
#define TRRO_CONFIG_UNEXIST          0x01000004 // 16777220:配置文件不存在
#define TRRO_CONFIG_CER_FAILED       0x01000005 // 16777221:云证书错误

/* 初始化模块，对应接口TrroLinux_start */
#define TRRO_INIT_ERROR              0x02FFFFFF  // 50331647:初始化通用失败
#define TRRO_INIT_INPUT_ILLEGAL      0x02000002  // 33554434:初始化参数异常
#define TRRO_INIT_PARSE_fAILED       0x02000003  // 33554435:配置节点解析异常
#define TRRO_INIT_CREAT_MEDIAMODE_FAILED     0x02000004  // 33554436:媒体模块创建失败
#define TRRO_INIT_LICENSE_CHECK_FAILED       0x02000005  // 33554437:LICENSE校验失败
#define TRRO_INIT_INVALUDE_INPUT       0x02000006  // 33554438:非法输入
#define TRRO_INIT_MQTT_ABNORMAL        0x02000007 // 33554439: 初始化mqtt异常
#define TRRO_INIT_REPEAT             0x02000008  // 33554440:重复初始化

/* 信令服务器模块 */
#define TRRO_SIGNAL_ERROR              0x03FFFFFF  // 67108863
#define TRRO_SIGNAL_REGIST_FAILED      0x03000002  // 50331650:信令注册失败
#define TRRO_SIGNAL_STATUS_ABNORMAL    0x03000003  // 50331651:信令服务器连接异常
#define TRRO_SIGNAL_MESSAGE_FAILED     0x03000004  // 50331652:信令消息处理失败
#define TRRO_SIGNAL_CONNECT_OUTTIME    0x03000005  // 50331653:信令服务器连接超时

/* 流采集模块 */
#define TRRO_CAPTURE_ERROR              0x04FFFFFF  // 83886079
#define TRRO_CAPTURE_OPENDEVICE_FAILED  0x04000002  // 67108866:打开设备失败
#define TRRO_CAPTURE_GETSOURCE_FAILED   0x04000003  // 67108867:获取数据源失败
#define TRRO_CAPTURE_UNKNOWN_CAPTURETYPE   0x04000004  // 67108868:未知采集类型

/* 流传输模块 */
#define TRRO_CONNECT_ERROR              0x05FFFFFF  // 100663295
#define TRRO_CONNECT_OUTTIME            0x05000002  // 83886082:超时断连
#define TRRO_CONNECT_RESET              0x05000003  // 83886083:connect的时候如果之前有未断开的连接需要重置
#define TRRO_CONNECT_MODE               0x05000004  // 83886084:connect网关的连接mode不支持

/* 诊断工具模块 */
#define TRRO_DIAG_STARTED               0x06000000  // 100663296: 诊断工具正在启动中
#define TRRO_DIAG_TIMEOUT               0x06000001  // 100663297: 诊断工具获取推流信息超时
#define TRRO_DIAG_FAILED                0x06000002  // 100663298: 诊断工具处理失败

/* 权限相关 */
#define TRRO_UNAUTHORIZED               0x07000000  // 117440512: 网关未授权无法发送消息

/* 消息通道 */
#define TRRO_MESSAGE_BYTE_EXCEED        0x08000002  // 134217730: 发送字节数超出限制


#ifdef __cplusplus
extern "C"
{
#endif

//操控权限
enum TrroPermission {
    kPermissionGuest = 0,
    kPermissionMaster = 1,
};


//视频连接状态
enum TrroState {
    kDisconnect = 0,
    kConnecting = 1,
    kConnected = 2,
    kDisconnecting = 3,
};

//日志等级
enum TrroLogLevel {
	TRRO_LOG_INFO = 1,
	TRRO_LOG_WARNING = 2,
	TRRO_LOG_ERROR = 3,
};

enum FrameType {
    TypeI420 = 0,
    TypeARGB = 1,
    TypeRGB  = 2,
    TYPENV12 = 3,
};

enum TrroCodec {
  Trro_H264 = 0,
  Trro_H265 = 1,
  Trro_AV1 = 2,
};

/**
 * SignalState 信令连接状态枚举
 */
enum SignalState {
    kTrroReady = 0, /**< 连接建立成功 */
    kTrroLost = 1,  /**< 连接断开，内部会进行自动重连 */
    kTrroReup = 2,  /**< 自动重连成功 */
    kTrroKickout = 3,
    kTrroAuthFailed = 4,  /**< 用户名或者密码错误 */
};

/* TRRO_OnMediaStateInfo 使用该结构体 包含媒体传输的详细信息
* fps         每秒帧数目
* bps         每秒数据量
* rtt         UDP ping网络往返时间
* decd        解码耗时ms
* jitter      接收抖动值
* packets_lost 总丢包数目
* packets_received 总接收数目
* stun         穿网模式 0：host, 1：srflx, 2：prflx, 3：relay
* 单位(%) 视频播放卡顿率 = 视频播放的累计卡顿时长 / 视频播放的总时长。
* lag_k100     视频帧间隔超过100ms视为卡顿，并将其计入视频播放的累计卡顿时长，最终计算获得的卡顿率。(音频暂不支持)
* lag_k150     视频帧间隔超过150ms视为卡顿，并将其计入视频播放的累计卡顿时长，最终计算获得的卡顿率。(音频暂不支持)
* duration     视频播放的总时长。(音频暂不支持)
*/
struct TrroMediaState {
    int fps;
    int bps;
    int rtt;
    long long decd;
    int jitter;
    long long packets_lost;
    long long packets_received;
    int stun;
    double lag_k100;
    double lag_k150;
    long long duration;
};


/*
* @name :  TRRO_onVideotimeReport (depreciated)
* @brief : 视频帧采集时间戳回调, 旧接口，建议使用onAllLatencyReport接口获取
* @input : context     回调上下文指针, 返回注册回调函数时传入的context
*          gwid        视频来源现场设备id
*          conn_fd     对应视频流接收句柄
*          videotime   当前视频帧的现场设备采集时间戳 (现场设备系统时钟)
* @return : void
*/
typedef void STD_CALL TRRO_onVideotimeReport(void* context, const char* gwid, int conn_fd, long long videotime);


/*
* @name :  TRRO_onLatencyReport (depreciated)
* @brief : 视频时延回调, 旧接口，建议使用onAllLatencyReport接口获取
* @input : context     回调上下文指针, 返回注册回调函数时传入的context
*          gwid        视频来源现场设备id
*          conn_fd     对应视频流接收句柄
*          latency     返回视频上行时延ms
* @return : void
*/
typedef void STD_CALL TRRO_onLatencyReport(void* context, const char* gwid, int conn_fd, long long latency);


/*
* @name :  TRRO_onAllLatencyReport
* @brief : 时延回调
* @input : context     回调上下文指针, 返回注册回调函数时传入的context
*          gwid        视频来源现场设备id
*          conn_fd     对应视频流接收句柄
*          latency1    返回视频上行时延ms
*          latency2    返回视频上行+控制下行延迟ms
*          videotime   当前视频帧的现场设备采集时间戳 (现场设备系统时钟)
*          rcct        控制信道往返时延ms, 等于控制上行延迟+控制下行延迟
* @return : void
*/
typedef void STD_CALL TRRO_onAllLatencyReport(void* context, const char* gwid, int conn_fd, long long latency1, long long latency2, long long videotime, int rcct);


/*
* @name :  TRRO_onReportData
* @brief : 接收来自现场设备信息回调
* @input : context     回调上下文指针, 返回注册回调函数时传入的context
*          gwid        消息来源现场设备id 
*          msg         消息, 二进制透传
*          len         消息长度
*          qos         消息来源传输qos， 0:不可靠传输, 1:可靠传输
* @return : void
*/
typedef void STD_CALL TRRO_onReportData(void* context, const char* gwid, const char* msg, int len, int qos);

/*
* @name :  TRRO_onRemoteFrameData
* @brief : 原始视频图像帧回调
* @input : context     回调上下文指针, 返回注册回调函数时传入的context
*          gwid        视频帧的来源现场设备id
*          stream_id   视频帧的来源现场设备流id
*          conn_fd     接收视频流的句柄标识
*          data        视频图像帧数据，数据格式为YUVI420，可通过I4202ARGB接口转ARGB
*          width       视频帧宽
*          height      视频帧高
*          videotime   当前视频帧的采集时间戳 (视频帧独立时钟)
* @return : void
*/
typedef void STD_CALL TRRO_onRemoteFrameData(void* context, const char* gwid, int stream_id, int conn_fd, const char* data, int width, int height, long long videotime);


/*
 * @name :  TRRO_onRemoteEncodedFrameData
 * @brief : 编码视频图像帧回调
 * @input : context       回调上下文指针, 返回注册回调函数时传入的context
 *          gwid          视频帧的来源现场设备id
 *          stream_id     视频帧的来源现场设备流id
 *          conn_fd       接收视频流的句柄标识
 *          data          编码的视频图像帧数据
 *          len           编码的视频图像帧的长度
 *          trro_codec    编码的codec类型
 *          is_key_frame  是否是关键帧
 *          videotime     当前视频帧的采集时间戳 (视频帧独立时钟)
 * @return : void
 */
typedef void STD_CALL TRRO_onRemoteEncodedFrameData(void* context, const char* gwid, int stream_id, int conn_fd,
                                                    const char* data, int len, TrroCodec trro_codec, bool is_key_frame,
                                                    long long videotime);

/*
* @name :  TRRO_OnState
* @brief : 视频流连接状态回调
* @input : context     回调上下文指针, 返回注册回调函数时传入的context
*          gwid        视频帧的来源现场设备id
*          stream_id   视频帧的来源现场设备流id
*          conn_fd     接收视频流的句柄标识
*          state       视频流连接状态，对应TrroState状态
* @return : void
*/
typedef void STD_CALL TRRO_OnState(void* context, const char* gwid, int stream_id, int conn_fd, int state);

/*
* @name :  TRRO_OnMediaState
* @brief : 视频流传输状态回调
* @input : context     回调上下文指针, 返回注册回调函数时传入的context
*          conn_fd     接收视频流的句柄标识
*          fps         每秒帧数目
*          bps         每秒数据量
*          rtt         UDP ping网络往返时间
*          decd        解帧耗时ms
*          jitter      接收抖动值
*          packets_lost 总丢包数目
*          packets_received 总接收数目
*          stun         穿网模式 0：host, 1：srflx, 2：prflx, 3：relay
* @return : void
*/
typedef void STD_CALL TRRO_OnMediaState(void* context, int conn_fd, int fps, int bps, int rtt, long long decd, int jitter,
    long long packets_lost, long long packets_received, int stun);


/*
* @name :  TRRO_OnMediaStateInfo
* @brief : 视频流传输状态回调
* @input : context     回调上下文指针, 返回注册回调函数时传入的context
*          conn_fd     接收视频流的句柄标识
*          mediastate  媒体相关的详细信息
* @return : void
*/
typedef void STD_CALL TRRO_OnMediaStateInfo(void* context, int conn_fd, TrroMediaState mediastate);

/*
* @name :  TRRO_OnAudioMediaStateInfo
* @brief : 视频流传输状态回调
* @input : context     回调上下文指针, 返回注册回调函数时传入的context
*          conn_fd     接收视频流的句柄标识
*          mediastate  媒体相关的详细信息
* @return : void
*/
typedef void STD_CALL TRRO_OnAudioMediaStateInfo(void* context, int conn_fd, TrroMediaState mediastate);

/*
* @name :   TRRO_OnLogData
* @brief :  日志回调
* @input :  context        回调上下文指针, 返回注册回调函数时传入的context
*           msg            日志内容
*           level          日志级别,参考枚举TrroLogLevel
* @return : void
*/
typedef void STD_CALL TRRO_OnLogData(void* context, const char* msg, int level);


/*
* #name :   TRRO_OnDiagReport
* @brief :  诊断信息回调
* @input :  context      回调上下文指针, 返回注册回调函数时传入的context
*           gwid         发起诊断的目标现场设备id
*           type         1 成功 , < 0 相关错误信息 
*           json         回调诊断详细信息 json格式
* @return : void
*/
typedef void STD_CALL TRRO_OnDiagReport(void* context, const char* gwid, int type, const char* json);

/*
* #name :   TRRO_OnOperationPermissionState
* @brief :  回调现场设备操控权限状态通知
* @input :  context             回调上下文指针, 返回注册回调函数时传入的context
*           field_devid         来源现场设备id
*           self_permission     本设备当前的操控权限，参考TrroPermission， 0 是guest，只有观看权限， 1是master，拥有完全控制权限
*           master_devid        拥有master权限的远端设备id
* @return : void
*/
typedef void STD_CALL TRRO_OnOperationPermissionState(void* context, const char* field_devid, int self_permission, const char* master_devid);



/**
* @name : TRRO_onFieldSideMediaState
* @brief : field端网络状态信息，server模式时有意义
* @input :       context            上下文
*                gwid               field端ID
*                stream_id          field端流ID
*                fps                field端推送帧率
*                bps                field端推送码率
*                rtt                field端封包来回时间
*                jitter             field端抖动
*                lost               field端丢包率
* @return : void
*/
typedef void TRRO_onFieldSideMediaState(void* context, const char* gwid, int stream_id, int fps, int bps, int rtt, int jitter, int lost);

/**
* @name TRRO_onSignalState
* @brief 信令连接状态回调
* @param[in]     context        上下文
* @param[in]     state          信令连接状态，参考枚举SignalState
* @return void
*/
typedef void TRRO_onSignalState(void *context, SignalState state);

/*
* @name :  TRRO_getGwList
* @brief : 获取在线现场设备设备列表，接口为同步阻塞模式.
* @input : void
* @return : json字符串, 使用方不需要释放指针, 获取到值后立即拷贝。
*           {"ret":0,"msg":"suc","gateways":[{"deviceID":"xx","name":"xx","type":"gateway","status":"connected","streams":4,"timestamp":1682231838673,"version":"xx"}],"count":1}
*/
extern "C" TRRO_EXPORT const char* TRRO_getGwList();

/*
* @name :  TRRO_getGwList
* @brief : 获取对应网关的版本，接口为同步阻塞模式.
* @input : gwid 设备id 公有云含projectID前缀/
* @return : json字符串, 使用方不需要释放指针, 获取到值后立即拷贝。
*           {"ret":0, "msg": "suc", "deviceID":"xx","name":"xx","type":"gateway","status":"connected","streams":4,"timestamp":1682231838673,"version":"xx","sdk_mode":"server2","ability":0,"licenseExpire":1745666980}
*/
extern "C" TRRO_EXPORT const char* TRRO_getGwInfo(const char* gwid);


/*
* @name :  TRRO_init (depreciated)
* @brief : SDK初始化，读取"./config.json"文件初始化， 接口为同步阻塞模式，等待信令连接成功后返回
* @input : void
* @return : 成功 1 失败 <= 0
*/
extern "C" TRRO_EXPORT int TRRO_init(); 

/*
* @name :  TRRO_initJsonPath
* @brief : SDK初始化，读取指定路径文件初始化， 接口为同步阻塞模式，等待信令连接成功后返回
* @input : jsonPath   json文件路径
* @return : 成功 1 失败 <= 0
*/
extern "C" TRRO_EXPORT int TRRO_initJsonPath(const char* jsonPath); 

/*
* @name :  TRRO_initJson
* @brief : SDK初始化，读取输入JSON字符串初始化， 接口为同步阻塞模式，等待信令连接成功后返回
* @input : json   json配置字符串
* @return : 成功 1 失败 <= 0
*/
extern "C" TRRO_EXPORT int TRRO_initJson(const char* json); 

/*
* @deprecated 这个接口已被废弃，不再推荐使用。请使用 TRRO_connectField 接口代替。
*/
extern "C" TRRO_EXPORT DEPRECATED int TRRO_connect(const char* gwid, const char* record_config, int streams_num, int* streams_id, int* conn_fds);

/*
* @name :  TRRO_connectField
* @brief : 发起视频连接，可多次调用连接不同流，异步模式，根据onState状态回调确认视频连接成功
* @input : gwid           目标连接的现场设备ID
*          streams_num    要拉取现场设备视频流的个数， 与conn_fds和streams_num数组长度匹配， 值的范围 1 到 现场设备支持的device_streams数量
*          streams_id     现场设备视频流的ID数组， 现场设备视频流ID从0开始， 最大值为现场设备支持的device_streams数量 -1
*          conn_fds       conn_fd数组，conn_fd为接收视频流的句柄标识，自行编号，取值从0开始，最大值为max_streams -1，max_streams在远端设备配置文件配置
*          compatible     是否开启版本兼容: 设置0，根据配置文件的“sdk_mode“字段来决定连接模式；设置为1，该接口会获取网关版本信息从而根据网关模式自动适配模式连接（由于需要获取版本信息会影响秒开）。默认值为0
*          record_config: 优先使用录制配置，当默认录制配置命名规则无法满足需求时使用，
                            json字符串，需要对每一路进行配置 eg:"{\"file_names\": [{\"file\":\"test\", \"duration\":15}, {\"file\":\"test01\", \"duration\":15}]}"  
                            ps:file 文件名 duration 分片时长单位秒; 不使用时默认为NULL
* @return : 成功 1 失败 <= 0
*/
extern "C" TRRO_EXPORT int TRRO_connectField(const char* gwid, int streams_num, int* streams_id, int* conn_fds, int compatible = 0, const char* record_config = NULL);

/*
* @name :  TRRO_setWindows
* @brief : 设置接收流句柄对应的显示窗口句柄
* @input : conn_fds 接收视频流句柄数组
*          windows  显示窗口句柄数组， 显示窗口句柄为显示窗体的句柄/指针，如windows平台的HWND；
*                   外部渲染时，数组中的显示窗口句柄配置为nullptr
*          num      设置显示窗口数量，与conn_fds和windows数组长度匹配
* @return : void
*/
extern "C" TRRO_EXPORT void TRRO_setWindows(int* conn_fds, WindowIdType * windows, int num);


/*
* @name :  TRRO_SetRenderConfig
* @brief : 设置接收流句柄对应的内部渲染模式, 仅内部渲染时使用
* @input : conn_fds 要设置渲染模式的接收视频流句柄数组
*          rotation 旋转角度 数组 rotation 为正顺时针旋转，rotation为负 逆时针旋转
*          scale 分辨率匹配模式数组 0 窗口拉伸， 1 保持原比例
*          config 预留渲染配置数组 0x00000XYZ X为1~2时开启夜视不同等级 推荐为2，Y为1时为开启超分模式，Z为1时为开启镜像渲染
*          num  配置的内部渲染流数量，与输入数组长度匹配
* @return : 成功 1 失败 <= 0
*/
extern "C" TRRO_EXPORT int TRRO_SetRenderConfig(int *conn_fds, int *rotation, int *scale, int *config, int num);



/*
* @name :  TRRO_disconnect
* @brief : 关闭conn_fds 对应的视频连接
* @input : conn_fds 要关闭视频连接对应的视频接收句柄数组
*          fd_num conn_fd数组长度
* @return : 成功 1 失败 <= 0
*/
extern "C" TRRO_EXPORT int TRRO_disconnect(int* conn_fds, int fd_num);

/*
* @name :  TRRO_disconnectAll
* @brief : 关闭所有视频连接
* @input : void
* @return : 成功 1 失败 <= 0
*/
extern "C" TRRO_EXPORT int TRRO_disconnectAll();


/*
* @name :  TRRO_sendControlData
* @brief : 给现场设备发送控制数据
* @input : gwid     目标现场设备id
*          msg      发送消息，二进制透传
*          len      消息长度  
*          qos      消息传输qos  0:不可靠传输 1:可靠传输
* @return : 成功 1 失败 <= 0
*/
extern "C" TRRO_EXPORT int TRRO_sendControlData(const char* gwid, const char* msg, int len, int qos = 0);


/*
* @name :  TRRO_audioMute
* @brief : Mute/unMute 目标现场设备的音频
* @input : gwid     目标现场设备id
*          mute     true 静音， false 取消静音
* @return : 成功 1 失败 <= 0
*/
extern "C" TRRO_EXPORT int TRRO_audioMute(const char* gwid, bool mute);

/* @name  TRRO_externAudioData
* @brief 外部音频数据输入(pcm数据), 16位音频采样
* @param[in]   data         源数据
* @param[in]   data_size    数据大小
* @param[in]   channel      音频声道数
* @param[in]   sample_rate  音频采样率
* @return 1 for success, other failed
*/
extern "C" TRRO_EXPORT int TRRO_externAudioData(const char* gwid, const char* data, int data_size, int channel, int sample_rate);

/*
* @name : TRRO_DiagRequest
* @brief : 需要主动出发，诊断网关、控制端当前状态输出报告
* @input : gwid     目标设备id
* @return : 成功1 失败 <= 0
*/
extern "C" TRRO_EXPORT int TRRO_diagRequest(const char* gwid);


/*
* @name : TRRO_requestPermission
* @brief : 向网关发出权限请求，网关会反馈TRRO_OnOperationPermissionState 更新权限
* @input : gwid         目标设备id
*          permisson    参考结构体 TrroPermission
* @return : 成功1 失败 <= 0
*/
extern "C" TRRO_EXPORT int TRRO_requestPermission(const char* gwid, int permisson);



/*
*   回调注册函数
*   context 上下文指针，回调时会返回注册时传入的该指针, 可用于回调类对象定位
*   callback 注册的回调函数，回调函数实现中请勿在回调线程长时间阻塞，若需要长时间处理建议转移到其他线程处理
*   frame_type 注册帧回调时需要的帧类型，参考FrameType 默认I420 0
*/
extern "C" TRRO_EXPORT void TRRO_registerLatencyCallback(void* context, TRRO_onLatencyReport * callback);
extern "C" TRRO_EXPORT void TRRO_registerAllLatencyCallback(void* context, TRRO_onAllLatencyReport * callback);
extern "C" TRRO_EXPORT void TRRO_registerVideotimeCallback(void* context, TRRO_onVideotimeReport * callback);
extern "C" TRRO_EXPORT void TRRO_registerReportDataCallback(void* context, TRRO_onReportData * callback);
extern "C" TRRO_EXPORT void TRRO_registerRemoteFrameCallback(void* context, TRRO_onRemoteFrameData * callback, int frame_type = 0);
extern "C" TRRO_EXPORT void TRRO_registerRemoteEncodedFrameCallback(void* context, TRRO_onRemoteEncodedFrameData* callback);
extern "C" TRRO_EXPORT void TRRO_registerOnState(void* context, TRRO_OnState * callback);
extern "C" TRRO_EXPORT void TRRO_registerOnMediaState(void* context, TRRO_OnMediaState * callback);
extern "C" TRRO_EXPORT void TRRO_registerOnMediaStateInfo(void* context, TRRO_OnMediaStateInfo * callback);
extern "C" TRRO_EXPORT int TRRO_registerLogCallback(void* context, TRRO_OnLogData * callback);
extern "C" TRRO_EXPORT void TRRO_registerOnDiagReport(void* context, TRRO_OnDiagReport * callback);
extern "C" TRRO_EXPORT void TRRO_registerOnOperationPermissionState(void* context, TRRO_OnOperationPermissionState* callback);
extern "C" TRRO_EXPORT void TRRO_registerFieldSideNetworkState(void* context, TRRO_onFieldSideMediaState * callback);
extern "C" TRRO_EXPORT void TRRO_registerOnAudioMediaStateInfo(void *context, TRRO_OnAudioMediaStateInfo * callback);


/**
* @name   TRRO_registerSignalStateCallback
* @brief  注册信令服务连接状态回调
* @param[in]   context              上下文
* @param[in]   callback             回调函数
* @return 1 for success, other failed
*/
extern "C" TRRO_EXPORT int TRRO_registerSignalStateCallback(void *context, TRRO_onSignalState *callback);

//获取SDK版本号
extern "C" TRRO_EXPORT const char* TRRO_getVersion();

//销毁SDK，释放资源
extern "C" TRRO_EXPORT void TRRO_destroy();


/*
* @name :  TRRO_I4202ARGB
* @brief : YUV I420图像格式转ARGB图像格式，转换时带resize功能
* @input : argb     存放输出ARGB图像数据的指针，ARGB的int表示： 0XFF(RR)(GG)(BB)  ，  RR GG BB为对应的rgb的值
*          yuvI420  输入yuvI420图像数据指针
*          src_width  输入图像宽度
*          src_height  输入图像高度
*          dst_width   输出图像宽度
*          dst_height  输出图像高度
* @return : 成功 1 失败 <= 0
*/
extern "C" TRRO_EXPORT int TRRO_I4202ARGB(int* argb, char* yuvI420, int src_width, int src_height, int dst_width, int dst_height);

// 现场设备RTC重配置，暂不开放
extern "C" TRRO_EXPORT int TRRO_reinitRtc(const char* gwid, int streams_id, const char* config); 
extern "C" TRRO_EXPORT int TRRO_digitalResize(const char* gwid, int streams_id, int x1, int y1, int x2, int y2, int display_width, int display_height);
extern "C" TRRO_EXPORT int TRRO_digitalResizeDouble(const char* gwid, int streams_id, int x1, int y1, int x2, int y2, int x3, int y3, int x4, int y4, int display_width, int display_height);

/*
* @name :  TRRO_fieldDeviceEncodeConfig
* @brief : 更新现场设备目标视频流编码参数
* @input : gwid 现场设备id
*          streams_id 目标视频流编号
*          encode_config 待更新的编码参数，json格式字符串，缺省字段将保持当前值不进行更新。 下面是更新支持的编码参数示意
*  {
*       "fps": 30,
*       "encode_width": 1920,
*       "encode_height": 1080,
*       "bps": 3000,
*       "min_fps": 30,
*       "min_bps": 1800,
*       "force_min": 0,
*       "min_width": 1920 
*  }
*/
extern "C" TRRO_EXPORT int TRRO_fieldDeviceEncodeConfig(const char* gwid, int streams_id, const char* encode_config);

//是否使用外部解码(只针对视频)
extern "C" TRRO_EXPORT int TRRO_useExternalDecoder(bool external);

/*
* @name :  TRRO_startMediaPush
* @brief : 开启rtmp/rtsp转推，调用TRRO_stopMediaPush停止，当调用connect/disconnect函数后conn_fd连接的视频流发生切流或断开时，也会自动停止推流，需要重新start才能推流
* @input : conn_fd     接收视频流的句柄标识
*          path        推流地址
* @return : 成功 1 失败 <= 0
*/
extern "C" TRRO_EXPORT int TRRO_startMediaPush(int conn_fd, const char* path);

/*
* @name :  TRRO_stopMediaPush
* @brief : 停止rtmp/rtsp转推
* @input : conn_fd     接收视频流的句柄标识
* @return : 成功 1 失败 <= 0
*/
extern "C" TRRO_EXPORT int TRRO_stopMediaPush(int conn_fd);

#ifdef __cplusplus
}
#endif


#endif





